@@ -37,7 +37,6 @@ class HostVirtualSwitch(
         host_system_id: builtins.str,
         name: builtins.str,
         network_adapters: typing.Sequence[builtins.str],
-        standby_nics: typing.Sequence[builtins.str],
         allow_forged_transmits: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         allow_mac_changes: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         allow_promiscuous: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
@@ -54,6 +53,7 @@ class HostVirtualSwitch(
         shaping_burst_size: typing.Optional[jsii.Number] = None,
         shaping_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         shaping_peak_bandwidth: typing.Optional[jsii.Number] = None,
+        standby_nics: typing.Optional[typing.Sequence[builtins.str]] = None,
         teaming_policy: typing.Optional[builtins.str] = None,
         connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
@@ -71,7 +71,6 @@ class HostVirtualSwitch(
         :param host_system_id: The managed object ID of the host to set the virtual switch up on. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#host_system_id HostVirtualSwitch#host_system_id}
         :param name: The name of the virtual switch. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#name HostVirtualSwitch#name}
         :param network_adapters: The list of network adapters to bind to this virtual switch. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#network_adapters HostVirtualSwitch#network_adapters}
-        :param standby_nics: List of standby network adapters used for failover. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#standby_nics HostVirtualSwitch#standby_nics}
         :param allow_forged_transmits: Controls whether or not the virtual network adapter is allowed to send network traffic with a different MAC address than that of its own. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#allow_forged_transmits HostVirtualSwitch#allow_forged_transmits}
         :param allow_mac_changes: Controls whether or not the Media Access Control (MAC) address can be changed. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#allow_mac_changes HostVirtualSwitch#allow_mac_changes}
         :param allow_promiscuous: Enable promiscuous mode on the network. This flag indicates whether or not all traffic is seen on a given port. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#allow_promiscuous HostVirtualSwitch#allow_promiscuous}
@@ -88,6 +87,7 @@ class HostVirtualSwitch(
         :param shaping_burst_size: The maximum burst size allowed in bytes if traffic shaping is enabled. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#shaping_burst_size HostVirtualSwitch#shaping_burst_size}
         :param shaping_enabled: Enable traffic shaping on this virtual switch or port group. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#shaping_enabled HostVirtualSwitch#shaping_enabled}
         :param shaping_peak_bandwidth: The peak bandwidth during bursts in bits per second if traffic shaping is enabled. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#shaping_peak_bandwidth HostVirtualSwitch#shaping_peak_bandwidth}
+        :param standby_nics: List of standby network adapters used for failover. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#standby_nics HostVirtualSwitch#standby_nics}
         :param teaming_policy: The network adapter teaming policy. Can be one of loadbalance_ip, loadbalance_srcmac, loadbalance_srcid, or failover_explicit. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#teaming_policy HostVirtualSwitch#teaming_policy}
         :param connection: 
         :param count: 
@@ -106,7 +106,6 @@ class HostVirtualSwitch(
             host_system_id=host_system_id,
             name=name,
             network_adapters=network_adapters,
-            standby_nics=standby_nics,
             allow_forged_transmits=allow_forged_transmits,
             allow_mac_changes=allow_mac_changes,
             allow_promiscuous=allow_promiscuous,
@@ -123,6 +122,7 @@ class HostVirtualSwitch(
             shaping_burst_size=shaping_burst_size,
             shaping_enabled=shaping_enabled,
             shaping_peak_bandwidth=shaping_peak_bandwidth,
+            standby_nics=standby_nics,
             teaming_policy=teaming_policy,
             connection=connection,
             count=count,
@@ -199,6 +199,10 @@ class HostVirtualSwitch(
     def reset_shaping_peak_bandwidth(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetShapingPeakBandwidth", []))
 
+    @jsii.member(jsii_name="resetStandbyNics")
+    def reset_standby_nics(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetStandbyNics", []))
+
     @jsii.member(jsii_name="resetTeamingPolicy")
     def reset_teaming_policy(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetTeamingPolicy", []))
@@ -647,7 +651,6 @@ class HostVirtualSwitch(
         "host_system_id": "hostSystemId",
         "name": "name",
         "network_adapters": "networkAdapters",
-        "standby_nics": "standbyNics",
         "allow_forged_transmits": "allowForgedTransmits",
         "allow_mac_changes": "allowMacChanges",
         "allow_promiscuous": "allowPromiscuous",
@@ -664,6 +667,7 @@ class HostVirtualSwitch(
         "shaping_burst_size": "shapingBurstSize",
         "shaping_enabled": "shapingEnabled",
         "shaping_peak_bandwidth": "shapingPeakBandwidth",
+        "standby_nics": "standbyNics",
         "teaming_policy": "teamingPolicy",
     },
 )
@@ -682,7 +686,6 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         host_system_id: builtins.str,
         name: builtins.str,
         network_adapters: typing.Sequence[builtins.str],
-        standby_nics: typing.Sequence[builtins.str],
         allow_forged_transmits: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         allow_mac_changes: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         allow_promiscuous: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
@@ -699,6 +702,7 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         shaping_burst_size: typing.Optional[jsii.Number] = None,
         shaping_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         shaping_peak_bandwidth: typing.Optional[jsii.Number] = None,
+        standby_nics: typing.Optional[typing.Sequence[builtins.str]] = None,
         teaming_policy: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -713,7 +717,6 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param host_system_id: The managed object ID of the host to set the virtual switch up on. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#host_system_id HostVirtualSwitch#host_system_id}
         :param name: The name of the virtual switch. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#name HostVirtualSwitch#name}
         :param network_adapters: The list of network adapters to bind to this virtual switch. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#network_adapters HostVirtualSwitch#network_adapters}
-        :param standby_nics: List of standby network adapters used for failover. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#standby_nics HostVirtualSwitch#standby_nics}
         :param allow_forged_transmits: Controls whether or not the virtual network adapter is allowed to send network traffic with a different MAC address than that of its own. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#allow_forged_transmits HostVirtualSwitch#allow_forged_transmits}
         :param allow_mac_changes: Controls whether or not the Media Access Control (MAC) address can be changed. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#allow_mac_changes HostVirtualSwitch#allow_mac_changes}
         :param allow_promiscuous: Enable promiscuous mode on the network. This flag indicates whether or not all traffic is seen on a given port. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#allow_promiscuous HostVirtualSwitch#allow_promiscuous}
@@ -730,6 +733,7 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         :param shaping_burst_size: The maximum burst size allowed in bytes if traffic shaping is enabled. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#shaping_burst_size HostVirtualSwitch#shaping_burst_size}
         :param shaping_enabled: Enable traffic shaping on this virtual switch or port group. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#shaping_enabled HostVirtualSwitch#shaping_enabled}
         :param shaping_peak_bandwidth: The peak bandwidth during bursts in bits per second if traffic shaping is enabled. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#shaping_peak_bandwidth HostVirtualSwitch#shaping_peak_bandwidth}
+        :param standby_nics: List of standby network adapters used for failover. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#standby_nics HostVirtualSwitch#standby_nics}
         :param teaming_policy: The network adapter teaming policy. Can be one of loadbalance_ip, loadbalance_srcmac, loadbalance_srcid, or failover_explicit. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#teaming_policy HostVirtualSwitch#teaming_policy}
         '''
         if isinstance(lifecycle, dict):
@@ -747,7 +751,6 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument host_system_id", value=host_system_id, expected_type=type_hints["host_system_id"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument network_adapters", value=network_adapters, expected_type=type_hints["network_adapters"])
-            check_type(argname="argument standby_nics", value=standby_nics, expected_type=type_hints["standby_nics"])
             check_type(argname="argument allow_forged_transmits", value=allow_forged_transmits, expected_type=type_hints["allow_forged_transmits"])
             check_type(argname="argument allow_mac_changes", value=allow_mac_changes, expected_type=type_hints["allow_mac_changes"])
             check_type(argname="argument allow_promiscuous", value=allow_promiscuous, expected_type=type_hints["allow_promiscuous"])
@@ -764,13 +767,13 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             check_type(argname="argument shaping_burst_size", value=shaping_burst_size, expected_type=type_hints["shaping_burst_size"])
             check_type(argname="argument shaping_enabled", value=shaping_enabled, expected_type=type_hints["shaping_enabled"])
             check_type(argname="argument shaping_peak_bandwidth", value=shaping_peak_bandwidth, expected_type=type_hints["shaping_peak_bandwidth"])
+            check_type(argname="argument standby_nics", value=standby_nics, expected_type=type_hints["standby_nics"])
             check_type(argname="argument teaming_policy", value=teaming_policy, expected_type=type_hints["teaming_policy"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "active_nics": active_nics,
             "host_system_id": host_system_id,
             "name": name,
             "network_adapters": network_adapters,
-            "standby_nics": standby_nics,
         }
         if connection is not None:
             self._values["connection"] = connection
@@ -818,6 +821,8 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
             self._values["shaping_enabled"] = shaping_enabled
         if shaping_peak_bandwidth is not None:
             self._values["shaping_peak_bandwidth"] = shaping_peak_bandwidth
+        if standby_nics is not None:
+            self._values["standby_nics"] = standby_nics
         if teaming_policy is not None:
             self._values["teaming_policy"] = teaming_policy
 
@@ -923,16 +928,6 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         assert result is not None, "Required property 'network_adapters' is missing"
         return typing.cast(typing.List[builtins.str], result)
 
-    @builtins.property
-    def standby_nics(self) -> typing.List[builtins.str]:
-        '''List of standby network adapters used for failover.
-
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#standby_nics HostVirtualSwitch#standby_nics}
-        '''
-        result = self._values.get("standby_nics")
-        assert result is not None, "Required property 'standby_nics' is missing"
-        return typing.cast(typing.List[builtins.str], result)
-
     @builtins.property
     def allow_forged_transmits(
         self,
@@ -1096,6 +1091,15 @@ class HostVirtualSwitchConfig(_cdktf_9a9027ec.TerraformMetaArguments):
         result = self._values.get("shaping_peak_bandwidth")
         return typing.cast(typing.Optional[jsii.Number], result)
 
+    @builtins.property
+    def standby_nics(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''List of standby network adapters used for failover.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/host_virtual_switch#standby_nics HostVirtualSwitch#standby_nics}
+        '''
+        result = self._values.get("standby_nics")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     @builtins.property
     def teaming_policy(self) -> typing.Optional[builtins.str]:
         '''The network adapter teaming policy. Can be one of loadbalance_ip, loadbalance_srcmac, loadbalance_srcid, or failover_explicit.
@@ -1132,7 +1136,6 @@ def _typecheckingstub__0cdfb02f4bbc45d69b2415d460e38b63ca07e802b7c38ef48484e7104
     host_system_id: builtins.str,
     name: builtins.str,
     network_adapters: typing.Sequence[builtins.str],
-    standby_nics: typing.Sequence[builtins.str],
     allow_forged_transmits: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     allow_mac_changes: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     allow_promiscuous: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
@@ -1149,6 +1152,7 @@ def _typecheckingstub__0cdfb02f4bbc45d69b2415d460e38b63ca07e802b7c38ef48484e7104
     shaping_burst_size: typing.Optional[jsii.Number] = None,
     shaping_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     shaping_peak_bandwidth: typing.Optional[jsii.Number] = None,
+    standby_nics: typing.Optional[typing.Sequence[builtins.str]] = None,
     teaming_policy: typing.Optional[builtins.str] = None,
     connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
     count: typing.Optional[jsii.Number] = None,
@@ -1306,7 +1310,6 @@ def _typecheckingstub__b871735f286129dab91cb1fda079e52a5692596f132de552bdb7689a8
     host_system_id: builtins.str,
     name: builtins.str,
     network_adapters: typing.Sequence[builtins.str],
-    standby_nics: typing.Sequence[builtins.str],
     allow_forged_transmits: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     allow_mac_changes: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     allow_promiscuous: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
@@ -1323,6 +1326,7 @@ def _typecheckingstub__b871735f286129dab91cb1fda079e52a5692596f132de552bdb7689a8
     shaping_burst_size: typing.Optional[jsii.Number] = None,
     shaping_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     shaping_peak_bandwidth: typing.Optional[jsii.Number] = None,
+    standby_nics: typing.Optional[typing.Sequence[builtins.str]] = None,
     teaming_policy: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
