@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class ResourcePool(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-vsphere.resourcePool.ResourcePool",
 ):
@@ -30,32 +30,32 @@ class ResourcePool(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         name: builtins.str,
         parent_resource_pool_id: builtins.str,
-        cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         cpu_limit: typing.Optional[jsii.Number] = None,
         cpu_reservation: typing.Optional[jsii.Number] = None,
         cpu_share_level: typing.Optional[builtins.str] = None,
         cpu_shares: typing.Optional[jsii.Number] = None,
         custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
-        memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         memory_reservation: typing.Optional[jsii.Number] = None,
         memory_share_level: typing.Optional[builtins.str] = None,
         memory_shares: typing.Optional[jsii.Number] = None,
         scale_descendants_shares: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/vsphere/r/resource_pool vsphere_resource_pool} Resource.
 
@@ -86,36 +86,7 @@ class ResourcePool(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id_: builtins.str,
-                *,
-                name: builtins.str,
-                parent_resource_pool_id: builtins.str,
-                cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                cpu_limit: typing.Optional[jsii.Number] = None,
-                cpu_reservation: typing.Optional[jsii.Number] = None,
-                cpu_share_level: typing.Optional[builtins.str] = None,
-                cpu_shares: typing.Optional[jsii.Number] = None,
-                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                id: typing.Optional[builtins.str] = None,
-                memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                memory_limit: typing.Optional[jsii.Number] = None,
-                memory_reservation: typing.Optional[jsii.Number] = None,
-                memory_share_level: typing.Optional[builtins.str] = None,
-                memory_shares: typing.Optional[jsii.Number] = None,
-                scale_descendants_shares: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0f671192bf7b80e53eab24f312c506992e20c490515b64c1c6b063af53486880)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ResourcePoolConfig(
@@ -215,8 +186,8 @@ class ResourcePool(
     @jsii.member(jsii_name="cpuExpandableInput")
     def cpu_expandable_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "cpuExpandableInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "cpuExpandableInput"))
 
     @builtins.property
     @jsii.member(jsii_name="cpuLimitInput")
@@ -254,8 +225,8 @@ class ResourcePool(
     @jsii.member(jsii_name="memoryExpandableInput")
     def memory_expandable_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "memoryExpandableInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "memoryExpandableInput"))
 
     @builtins.property
     @jsii.member(jsii_name="memoryLimitInput")
@@ -299,18 +270,18 @@ class ResourcePool(
 
     @builtins.property
     @jsii.member(jsii_name="cpuExpandable")
-    def cpu_expandable(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "cpuExpandable"))
+    def cpu_expandable(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "cpuExpandable"))
 
     @cpu_expandable.setter
     def cpu_expandable(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b01c8bcecac5dc3d0bcbb068fa7c00a941bff83d91fe866e9548f947e788c376)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuExpandable", value)
 
@@ -322,9 +293,7 @@ class ResourcePool(
     @cpu_limit.setter
     def cpu_limit(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3337f01f1ec9577ecc4206349dcf60036f4ee375a7b532c80b2066f8973f2a4b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuLimit", value)
 
@@ -336,9 +305,7 @@ class ResourcePool(
     @cpu_reservation.setter
     def cpu_reservation(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__11224e0d77984915169350b1edcc849159e63cf2729a97ca32f321f8cb0ec477)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuReservation", value)
 
@@ -350,9 +317,7 @@ class ResourcePool(
     @cpu_share_level.setter
     def cpu_share_level(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e6f0d7df228ced5e1da01e054c6e8fb95e197c1d3add078af5da2fa20eb381ef)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuShareLevel", value)
 
@@ -364,9 +329,7 @@ class ResourcePool(
     @cpu_shares.setter
     def cpu_shares(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f2244c876d64c0ae8e684547f0cacbe1e92c0f1455b688e432771b5ad72b6528)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuShares", value)
 
@@ -381,9 +344,7 @@ class ResourcePool(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0f3b1f8118484ca40379acc0d42ef6746587939c4eb3a9e7b6efb7a179013b1c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "customAttributes", value)
 
@@ -395,26 +356,24 @@ class ResourcePool(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__994b6d80edad0667887c574db73d645fc1b3dc37b841aaeef107e661727eaa5c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
     @builtins.property
     @jsii.member(jsii_name="memoryExpandable")
-    def memory_expandable(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "memoryExpandable"))
+    def memory_expandable(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "memoryExpandable"))
 
     @memory_expandable.setter
     def memory_expandable(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b169853ac86c777e8006db5f3b001dc3b04c18f33faaf8734a19d3d97cc3f48c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryExpandable", value)
 
@@ -426,9 +385,7 @@ class ResourcePool(
     @memory_limit.setter
     def memory_limit(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b2029039ebfd72d8622ae4397da794bfb54fc9f824758598e3ea0c9d61ace21f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryLimit", value)
 
@@ -440,9 +397,7 @@ class ResourcePool(
     @memory_reservation.setter
     def memory_reservation(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7f5293fffcce8f8694d155ea270852c0293fa8a2a7b6526a76b7b6689a2916b1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryReservation", value)
 
@@ -454,9 +409,7 @@ class ResourcePool(
     @memory_share_level.setter
     def memory_share_level(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__30f6125748e63eee8ba63918ef2fb7b61e889f14191be56aea50e394deb906e7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryShareLevel", value)
 
@@ -468,9 +421,7 @@ class ResourcePool(
     @memory_shares.setter
     def memory_shares(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d0fff67904822195913476c1ffb29f34cd6d59315bb1f8677630bfab5bc37aba)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryShares", value)
 
@@ -482,9 +433,7 @@ class ResourcePool(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7314ec75e4d475d59159694f1f53631424cb395d18211b8e1913358c78e2d91a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -496,9 +445,7 @@ class ResourcePool(
     @parent_resource_pool_id.setter
     def parent_resource_pool_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__294f3ca5324d4124bdeb95f93d21ff14ff9f0802405a4173de1fdde9582abfcd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "parentResourcePoolId", value)
 
@@ -510,9 +457,7 @@ class ResourcePool(
     @scale_descendants_shares.setter
     def scale_descendants_shares(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3a07b9154adb1c31b52a58bf7dbee1f05ddb7d78a0aed14c9fc88f1533b507f3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scaleDescendantsShares", value)
 
@@ -524,16 +469,14 @@ class ResourcePool(
     @tags.setter
     def tags(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.List[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6e14ce4031025b5dff23c5178fce56e4c1e970a772f9f1ef311eee368f0d4091)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-vsphere.resourcePool.ResourcePoolConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -560,27 +503,27 @@ class ResourcePool(
         "tags": "tags",
     },
 )
-class ResourcePoolConfig(cdktf.TerraformMetaArguments):
+class ResourcePoolConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: builtins.str,
         parent_resource_pool_id: builtins.str,
-        cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         cpu_limit: typing.Optional[jsii.Number] = None,
         cpu_reservation: typing.Optional[jsii.Number] = None,
         cpu_share_level: typing.Optional[builtins.str] = None,
         cpu_shares: typing.Optional[jsii.Number] = None,
         custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
-        memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         memory_reservation: typing.Optional[jsii.Number] = None,
         memory_share_level: typing.Optional[builtins.str] = None,
@@ -614,36 +557,9 @@ class ResourcePoolConfig(cdktf.TerraformMetaArguments):
         :param tags: A list of tag IDs to apply to this object. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/resource_pool#tags ResourcePool#tags}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                name: builtins.str,
-                parent_resource_pool_id: builtins.str,
-                cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                cpu_limit: typing.Optional[jsii.Number] = None,
-                cpu_reservation: typing.Optional[jsii.Number] = None,
-                cpu_share_level: typing.Optional[builtins.str] = None,
-                cpu_shares: typing.Optional[jsii.Number] = None,
-                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                id: typing.Optional[builtins.str] = None,
-                memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                memory_limit: typing.Optional[jsii.Number] = None,
-                memory_reservation: typing.Optional[jsii.Number] = None,
-                memory_share_level: typing.Optional[builtins.str] = None,
-                memory_shares: typing.Optional[jsii.Number] = None,
-                scale_descendants_shares: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0fc0ff662e5a6699843f3d396ea95a30e99d785c9402c7636de4e3088e425d74)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -667,7 +583,7 @@ class ResourcePoolConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument memory_shares", value=memory_shares, expected_type=type_hints["memory_shares"])
             check_type(argname="argument scale_descendants_shares", value=scale_descendants_shares, expected_type=type_hints["scale_descendants_shares"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "parent_resource_pool_id": parent_resource_pool_id,
         }
@@ -717,12 +633,12 @@ class ResourcePoolConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -733,46 +649,48 @@ class ResourcePoolConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def name(self) -> builtins.str:
@@ -797,13 +715,13 @@ class ResourcePoolConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def cpu_expandable(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Determines if the reservation on a resource pool can grow beyond the specified value, if the parent resource pool has unreserved resources.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/resource_pool#cpu_expandable ResourcePool#cpu_expandable}
         '''
         result = self._values.get("cpu_expandable")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def cpu_limit(self) -> typing.Optional[jsii.Number]:
@@ -871,13 +789,13 @@ class ResourcePoolConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def memory_expandable(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Determines if the reservation on a resource pool can grow beyond the specified value, if the parent resource pool has unreserved resources.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/resource_pool#memory_expandable ResourcePool#memory_expandable}
         '''
         result = self._values.get("memory_expandable")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def memory_limit(self) -> typing.Optional[jsii.Number]:
@@ -957,3 +875,159 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__0f671192bf7b80e53eab24f312c506992e20c490515b64c1c6b063af53486880(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    name: builtins.str,
+    parent_resource_pool_id: builtins.str,
+    cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    cpu_limit: typing.Optional[jsii.Number] = None,
+    cpu_reservation: typing.Optional[jsii.Number] = None,
+    cpu_share_level: typing.Optional[builtins.str] = None,
+    cpu_shares: typing.Optional[jsii.Number] = None,
+    custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    memory_reservation: typing.Optional[jsii.Number] = None,
+    memory_share_level: typing.Optional[builtins.str] = None,
+    memory_shares: typing.Optional[jsii.Number] = None,
+    scale_descendants_shares: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b01c8bcecac5dc3d0bcbb068fa7c00a941bff83d91fe866e9548f947e788c376(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3337f01f1ec9577ecc4206349dcf60036f4ee375a7b532c80b2066f8973f2a4b(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__11224e0d77984915169350b1edcc849159e63cf2729a97ca32f321f8cb0ec477(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e6f0d7df228ced5e1da01e054c6e8fb95e197c1d3add078af5da2fa20eb381ef(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f2244c876d64c0ae8e684547f0cacbe1e92c0f1455b688e432771b5ad72b6528(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0f3b1f8118484ca40379acc0d42ef6746587939c4eb3a9e7b6efb7a179013b1c(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__994b6d80edad0667887c574db73d645fc1b3dc37b841aaeef107e661727eaa5c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b169853ac86c777e8006db5f3b001dc3b04c18f33faaf8734a19d3d97cc3f48c(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b2029039ebfd72d8622ae4397da794bfb54fc9f824758598e3ea0c9d61ace21f(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7f5293fffcce8f8694d155ea270852c0293fa8a2a7b6526a76b7b6689a2916b1(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__30f6125748e63eee8ba63918ef2fb7b61e889f14191be56aea50e394deb906e7(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d0fff67904822195913476c1ffb29f34cd6d59315bb1f8677630bfab5bc37aba(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7314ec75e4d475d59159694f1f53631424cb395d18211b8e1913358c78e2d91a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__294f3ca5324d4124bdeb95f93d21ff14ff9f0802405a4173de1fdde9582abfcd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3a07b9154adb1c31b52a58bf7dbee1f05ddb7d78a0aed14c9fc88f1533b507f3(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6e14ce4031025b5dff23c5178fce56e4c1e970a772f9f1ef311eee368f0d4091(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0fc0ff662e5a6699843f3d396ea95a30e99d785c9402c7636de4e3088e425d74(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    name: builtins.str,
+    parent_resource_pool_id: builtins.str,
+    cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    cpu_limit: typing.Optional[jsii.Number] = None,
+    cpu_reservation: typing.Optional[jsii.Number] = None,
+    cpu_share_level: typing.Optional[builtins.str] = None,
+    cpu_shares: typing.Optional[jsii.Number] = None,
+    custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    memory_reservation: typing.Optional[jsii.Number] = None,
+    memory_share_level: typing.Optional[builtins.str] = None,
+    memory_shares: typing.Optional[jsii.Number] = None,
+    scale_descendants_shares: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
