@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class VappContainer(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-vsphere.vappContainer.VappContainer",
 ):
@@ -30,32 +30,32 @@ class VappContainer(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         name: builtins.str,
         parent_resource_pool_id: builtins.str,
-        cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         cpu_limit: typing.Optional[jsii.Number] = None,
         cpu_reservation: typing.Optional[jsii.Number] = None,
         cpu_share_level: typing.Optional[builtins.str] = None,
         cpu_shares: typing.Optional[jsii.Number] = None,
         custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
-        memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         memory_reservation: typing.Optional[jsii.Number] = None,
         memory_share_level: typing.Optional[builtins.str] = None,
         memory_shares: typing.Optional[jsii.Number] = None,
         parent_folder_id: typing.Optional[builtins.str] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/vsphere/r/vapp_container vsphere_vapp_container} Resource.
 
@@ -86,36 +86,7 @@ class VappContainer(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id_: builtins.str,
-                *,
-                name: builtins.str,
-                parent_resource_pool_id: builtins.str,
-                cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                cpu_limit: typing.Optional[jsii.Number] = None,
-                cpu_reservation: typing.Optional[jsii.Number] = None,
-                cpu_share_level: typing.Optional[builtins.str] = None,
-                cpu_shares: typing.Optional[jsii.Number] = None,
-                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                id: typing.Optional[builtins.str] = None,
-                memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                memory_limit: typing.Optional[jsii.Number] = None,
-                memory_reservation: typing.Optional[jsii.Number] = None,
-                memory_share_level: typing.Optional[builtins.str] = None,
-                memory_shares: typing.Optional[jsii.Number] = None,
-                parent_folder_id: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__31cef4d71d0934809b7ef0afc6b1fb62f6ff114eb0a6e859a3a5d85d1a7a8096)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = VappContainerConfig(
@@ -215,8 +186,8 @@ class VappContainer(
     @jsii.member(jsii_name="cpuExpandableInput")
     def cpu_expandable_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "cpuExpandableInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "cpuExpandableInput"))
 
     @builtins.property
     @jsii.member(jsii_name="cpuLimitInput")
@@ -254,8 +225,8 @@ class VappContainer(
     @jsii.member(jsii_name="memoryExpandableInput")
     def memory_expandable_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "memoryExpandableInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "memoryExpandableInput"))
 
     @builtins.property
     @jsii.member(jsii_name="memoryLimitInput")
@@ -299,18 +270,18 @@ class VappContainer(
 
     @builtins.property
     @jsii.member(jsii_name="cpuExpandable")
-    def cpu_expandable(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "cpuExpandable"))
+    def cpu_expandable(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "cpuExpandable"))
 
     @cpu_expandable.setter
     def cpu_expandable(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1b8af67494630cd88d63de6a70cf0c9ff7ce8a33f60847da3bcff0b6f02b7bec)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuExpandable", value)
 
@@ -322,9 +293,7 @@ class VappContainer(
     @cpu_limit.setter
     def cpu_limit(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__949d0a9f69b742fcd31b74183a9c724bcd272c38ce170a66085465610d66d716)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuLimit", value)
 
@@ -336,9 +305,7 @@ class VappContainer(
     @cpu_reservation.setter
     def cpu_reservation(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1f127875732a0d966d23419a401c807d0945a104df2f70bc446a26f8a927f24e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuReservation", value)
 
@@ -350,9 +317,7 @@ class VappContainer(
     @cpu_share_level.setter
     def cpu_share_level(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f2d2e6b2b04989b1af3e75e5b9ca7cce63a1077a6b8e44b630d8f52491ce5afe)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuShareLevel", value)
 
@@ -364,9 +329,7 @@ class VappContainer(
     @cpu_shares.setter
     def cpu_shares(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3aa05e1c042462cfe11ffa2086c5e330d00d3dc859557fe3c0dbf1d43399698f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cpuShares", value)
 
@@ -381,9 +344,7 @@ class VappContainer(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bd9aad77f646bc9a51742cd173913bc08befc037e4bf8768f5ce2421ae356c71)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "customAttributes", value)
 
@@ -395,26 +356,24 @@ class VappContainer(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0adba3b2976f48edd5853c1dd7698eae635e9c67d750dda9b671e53703027bb4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
     @builtins.property
     @jsii.member(jsii_name="memoryExpandable")
-    def memory_expandable(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "memoryExpandable"))
+    def memory_expandable(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "memoryExpandable"))
 
     @memory_expandable.setter
     def memory_expandable(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b99e01aaf27c719d56e5eafe83ca871ce8979786705f484c99ef181949b68a85)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryExpandable", value)
 
@@ -426,9 +385,7 @@ class VappContainer(
     @memory_limit.setter
     def memory_limit(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c1feb438101ba1762f73c7620078e59f9ebab969ca78c0624caaa985b802504a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryLimit", value)
 
@@ -440,9 +397,7 @@ class VappContainer(
     @memory_reservation.setter
     def memory_reservation(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__efea96baaa6a0900a043d04d5ac0c636851e094355b310245cbef8ccbea7a9ec)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryReservation", value)
 
@@ -454,9 +409,7 @@ class VappContainer(
     @memory_share_level.setter
     def memory_share_level(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__364341b3507b59260731e4029202074b337e3cffb5acc97b5ffe380aee9487f1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryShareLevel", value)
 
@@ -468,9 +421,7 @@ class VappContainer(
     @memory_shares.setter
     def memory_shares(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__03b0fc930362cc698cc31f81a646d463264c72ca98cd2f8f3bd04894eea60b1f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "memoryShares", value)
 
@@ -482,9 +433,7 @@ class VappContainer(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__774965be447da3c3b5569de10857e5f77906d51bf5257c480cbf8a0132e8594d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -496,9 +445,7 @@ class VappContainer(
     @parent_folder_id.setter
     def parent_folder_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2189e654641c3ed338d3e8d46d685bcb6e60df34af14e62bf0aa9dcbc322bb8b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "parentFolderId", value)
 
@@ -510,9 +457,7 @@ class VappContainer(
     @parent_resource_pool_id.setter
     def parent_resource_pool_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4b6cf494ff6f784a933e6f75303f8e5517b0cbf1bf5d06c328e582f13c9e3d9f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "parentResourcePoolId", value)
 
@@ -524,16 +469,14 @@ class VappContainer(
     @tags.setter
     def tags(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.List[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__970f02b3e436d938b70c748efcbbfd3531950f82f02730105b19de642aadc624)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-vsphere.vappContainer.VappContainerConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -560,27 +503,27 @@ class VappContainer(
         "tags": "tags",
     },
 )
-class VappContainerConfig(cdktf.TerraformMetaArguments):
+class VappContainerConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: builtins.str,
         parent_resource_pool_id: builtins.str,
-        cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         cpu_limit: typing.Optional[jsii.Number] = None,
         cpu_reservation: typing.Optional[jsii.Number] = None,
         cpu_share_level: typing.Optional[builtins.str] = None,
         cpu_shares: typing.Optional[jsii.Number] = None,
         custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
-        memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         memory_reservation: typing.Optional[jsii.Number] = None,
         memory_share_level: typing.Optional[builtins.str] = None,
@@ -614,36 +557,9 @@ class VappContainerConfig(cdktf.TerraformMetaArguments):
         :param tags: A list of tag IDs to apply to this object. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/vapp_container#tags VappContainer#tags}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                name: builtins.str,
-                parent_resource_pool_id: builtins.str,
-                cpu_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                cpu_limit: typing.Optional[jsii.Number] = None,
-                cpu_reservation: typing.Optional[jsii.Number] = None,
-                cpu_share_level: typing.Optional[builtins.str] = None,
-                cpu_shares: typing.Optional[jsii.Number] = None,
-                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                id: typing.Optional[builtins.str] = None,
-                memory_expandable: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                memory_limit: typing.Optional[jsii.Number] = None,
-                memory_reservation: typing.Optional[jsii.Number] = None,
-                memory_share_level: typing.Optional[builtins.str] = None,
-                memory_shares: typing.Optional[jsii.Number] = None,
-                parent_folder_id: typing.Optional[builtins.str] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4ef67a415f3a5eaa6887e33e37a97faa1045b4a581b0ffee2a4140b6746fc8d2)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -667,7 +583,7 @@ class VappContainerConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument memory_shares", value=memory_shares, expected_type=type_hints["memory_shares"])
             check_type(argname="argument parent_folder_id", value=parent_folder_id, expected_type=type_hints["parent_folder_id"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "parent_resource_pool_id": parent_resource_pool_id,
         }
@@ -717,12 +633,12 @@ class VappContainerConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -733,46 +649,48 @@ class VappContainerConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def name(self) -> builtins.str:
@@ -797,13 +715,13 @@ class VappContainerConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def cpu_expandable(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Determines if the reservation on a vApp container can grow beyond the specified value, if the parent resource pool has unreserved resources.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/vapp_container#cpu_expandable VappContainer#cpu_expandable}
         '''
         result = self._values.get("cpu_expandable")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def cpu_limit(self) -> typing.Optional[jsii.Number]:
@@ -871,13 +789,13 @@ class VappContainerConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def memory_expandable(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Determines if the reservation on a vApp container can grow beyond the specified value, if the parent resource pool has unreserved resources.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/vapp_container#memory_expandable VappContainer#memory_expandable}
         '''
         result = self._values.get("memory_expandable")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def memory_limit(self) -> typing.Optional[jsii.Number]:
@@ -957,3 +875,159 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__31cef4d71d0934809b7ef0afc6b1fb62f6ff114eb0a6e859a3a5d85d1a7a8096(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    name: builtins.str,
+    parent_resource_pool_id: builtins.str,
+    cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    cpu_limit: typing.Optional[jsii.Number] = None,
+    cpu_reservation: typing.Optional[jsii.Number] = None,
+    cpu_share_level: typing.Optional[builtins.str] = None,
+    cpu_shares: typing.Optional[jsii.Number] = None,
+    custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    memory_reservation: typing.Optional[jsii.Number] = None,
+    memory_share_level: typing.Optional[builtins.str] = None,
+    memory_shares: typing.Optional[jsii.Number] = None,
+    parent_folder_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1b8af67494630cd88d63de6a70cf0c9ff7ce8a33f60847da3bcff0b6f02b7bec(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__949d0a9f69b742fcd31b74183a9c724bcd272c38ce170a66085465610d66d716(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1f127875732a0d966d23419a401c807d0945a104df2f70bc446a26f8a927f24e(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f2d2e6b2b04989b1af3e75e5b9ca7cce63a1077a6b8e44b630d8f52491ce5afe(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3aa05e1c042462cfe11ffa2086c5e330d00d3dc859557fe3c0dbf1d43399698f(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bd9aad77f646bc9a51742cd173913bc08befc037e4bf8768f5ce2421ae356c71(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0adba3b2976f48edd5853c1dd7698eae635e9c67d750dda9b671e53703027bb4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b99e01aaf27c719d56e5eafe83ca871ce8979786705f484c99ef181949b68a85(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c1feb438101ba1762f73c7620078e59f9ebab969ca78c0624caaa985b802504a(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__efea96baaa6a0900a043d04d5ac0c636851e094355b310245cbef8ccbea7a9ec(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__364341b3507b59260731e4029202074b337e3cffb5acc97b5ffe380aee9487f1(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__03b0fc930362cc698cc31f81a646d463264c72ca98cd2f8f3bd04894eea60b1f(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__774965be447da3c3b5569de10857e5f77906d51bf5257c480cbf8a0132e8594d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2189e654641c3ed338d3e8d46d685bcb6e60df34af14e62bf0aa9dcbc322bb8b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4b6cf494ff6f784a933e6f75303f8e5517b0cbf1bf5d06c328e582f13c9e3d9f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__970f02b3e436d938b70c748efcbbfd3531950f82f02730105b19de642aadc624(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4ef67a415f3a5eaa6887e33e37a97faa1045b4a581b0ffee2a4140b6746fc8d2(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    name: builtins.str,
+    parent_resource_pool_id: builtins.str,
+    cpu_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    cpu_limit: typing.Optional[jsii.Number] = None,
+    cpu_reservation: typing.Optional[jsii.Number] = None,
+    cpu_share_level: typing.Optional[builtins.str] = None,
+    cpu_shares: typing.Optional[jsii.Number] = None,
+    custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    memory_expandable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    memory_reservation: typing.Optional[jsii.Number] = None,
+    memory_share_level: typing.Optional[builtins.str] = None,
+    memory_shares: typing.Optional[jsii.Number] = None,
+    parent_folder_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
